@@ -38,11 +38,11 @@ import subprocess
 import itertools
 import time
 import random
+import math
 import copy
 import datetime
 import os.path
 
-
 def auc(x, y, reorder=False): #from sklearn, http://scikit-learn.org, licensed under BSD License
     """Compute Area Under the Curve (AUC) using the trapezoidal rule
 
@@ -107,6 +107,19 @@ def auc(x, y, reorder=False): #from sklearn, http://scikit-learn.org, licensed u
     return area
 
 
+def mae(absolute_error_values):
+    if np is None:
+        return sum(absolute_error_values) / len(absolute_error_values)
+    else:
+        return np.mean(absolute_error_values)
+
+def rmse(squared_error_values):
+    if np is None:
+        return math.sqrt(sum(squared_error_values)/len(squared_error_values))
+    else:
+        return math.sqrt(np.mean(squared_error_values))
+
+
 class ProcessFailed(Exception):
     pass
 
@@ -118,7 +131,11 @@ class ConfusionMatrix(FrequencyList):
         """Print Confusion Matrix in table form"""
         o = "== Confusion Matrix == (hor: goals, vert: observations)\n\n"
 
-        keys = sorted( set( ( x[1] for x in self._count.keys()) ) )
+        keys = set()
+        for goalkey,observationkey in self._count.keys():
+            keys.add(goalkey)
+            keys.add(observationkey)
+        keys = sorted( keys)
 
         linemask = "%20s"
         cells = ['']
@@ -381,6 +398,34 @@ class ClassEvaluation(object):
         return str(self)
 
 
+class OrdinalEvaluation(ClassEvaluation):
+
+    def __init__(self,  goals = [], observations = [], missing = {}, encoding ='utf-8'):
+        ClassEvaluation.__init__(self,goals,observations,missing,encoding='utf-8')
+
+    def compute(self):
+        assert not False in [type(cls) == int for cls in self.classes]
+        ClassEvaluation.compute(self)
+        self.error = defaultdict(list)
+        self.squared_error = defaultdict(list)
+        for goal, observation in self:
+            self.error[observation].append(abs(goal-observation))
+            self.squared_error[observation].append(abs(goal-observation)**2)
+
+    def mae(self, cls=None):
+        if not self.computed: self.compute()
+        if cls:
+            return mae(self.error[cls])
+        else:
+            return mae(sum([self.error[x] for x in set(self.goals)], []))
+
+    def rmse(self, cls=None):
+        if not self.computed: self.compute()
+        if cls:
+            return rmse(self.squared_error[cls])
+        else:
+            return rmse(sum([self.squared_error[x] for x in set(self.goals)], []))
+
 class AbstractExperiment(object):
 
     def __init__(self, inputdata = None, **parameters):
